// TEcho_Hello.ino

// Programme d'Affichage du mot Hello à l'écran du module LILYGO T-ECHO.
// Adapté par Frank LOBA (www.f4hdb.fr).
// Date création : 10/02/2024.
// Dernière mise à jour : 10/02/2024.

// Programm zur Anzeige des Wortes Hello auf dem Bildschirm des LILYGO T-ECHO-Moduls.
// Adaptiert von Frank LOBA (www.f4hdb.fr).
// Erstellungsdatum: 10.02.2024.
// Letzte Aktualisierung: 10.02.2024.

// Program for displaying the word Hello on the screen of the LILYGO T-ECHO module.
// Adapted by Frank LOBA (www.f4hdb.fr).
// Creation date: 02/10/2024.
// Last update: 02/10/2024.


/**** INCLUSION DES BIBLIOTHEQUES GENERALES ****/
/**** EINBEZIEHUNG ALLGEMEINER BIBLIOTHEKEN ****/
/**** INCLUSION OF GENERAL LIBRARIES ****/
#include <Arduino.h>
#include <SPI.h>


/**** INCLUSION DES BIBLIOTHEQUES NECESSAIRES AU PILOTAGE DE L'ECRAN E-PAPER ****/
/**** EINSCHLUSS VON BIBLIOTHEKS, DIE ZUR STEUERUNG DES E-PAPER-BILDSCHIRMS ERFORDERLICH SIND ****/
/**** INCLUSION OF LIBRARIES REQUIRED TO CONTROL THE E-PAPER SCREEN ****/
#include <GxEPD.h>
#include <GxDEPG0150BN/GxDEPG0150BN.h>  // 1.54" b/w
#include <Fonts/FreeMonoBold9pt7b.h>
#include <GxIO/GxIO_SPI/GxIO_SPI.h>
#include <GxIO/GxIO.h>


/**** DEFINITION DE LA MACRO DE CALCUL DU NUMERO DE LA BROCHE ****/
/**** DEFINITION DES PIN-NUMMER-BERECHNUNGSMAKROS ****/
/**** DEFINITION OF THE PIN NUMBER CALCULATION MACRO ****/
#ifndef _PIN_NUMBER
#define _PIN_NUMBER(_PORT, _PIN)    ((_PORT << 5) + _PIN)  // = Port * 32 + Pin.
#endif


/**** DEFINITION DES NUMEROS DES BROCHES DE L'ECRAN E-PAPER ****/
/**** DEFINITION DER E-PAPER-BILDSCHIRM-PIN-NUMMERN ****/
/**** DEFINITION OF E-PAPER SCREEN PIN NUMBERS ****/
#define E_PAPER_MISO         _PIN_NUMBER(1,6)
#define E_PAPER_MOSI         _PIN_NUMBER(0,29)
#define E_PAPER_SCLK         _PIN_NUMBER(0,31)
#define E_PAPER_CS           _PIN_NUMBER(0,30)
#define E_PAPER_DC           _PIN_NUMBER(0,28)
#define E_PAPER_RST          _PIN_NUMBER(0,2)
#define E_PAPER_BUSY         _PIN_NUMBER(0,3)
#define E_PAPER_BACKLIGHT    _PIN_NUMBER(1,11)


/**** DECLARATION DES OBJETS NECESSAIRES POUR PILOTER L'ECRAN ****/
/**** ERKLÄRUNG DER ZUR STEUERUNG DES BILDSCHIRMS ERFORDERLICHEN OBJEKTE ****/
/**** DECLARATION OF OBJECTS NECESSARY TO CONTROL THE SCREEN ****/
SPIClass DisplayPort(NRF_SPIM2, E_PAPER_MISO, E_PAPER_SCLK, E_PAPER_MOSI);
GxIO_Class Io(DisplayPort, E_PAPER_CS, E_PAPER_DC, E_PAPER_RST);
GxEPD_Class Display(Io, E_PAPER_RST, E_PAPER_BUSY);


/**** DEFINITION DE LA FONCTION D'INITIALISATION DU MODULE LILYGO T-ECHO ****/
/**** DEFINITION DER INITIALISIERUNGSFUNKTION DES LILYGO T-ECHO-MODULS ****/
/**** DEFINITION OF THE INITIALIZATION FUNCTION OF THE LILYGO T-ECHO MODULE ****/
void setup()
{
    // Initialisation des objets de l'écran.
    // Initialisierung von Bildschirmobjekten.
    // Initialization of screen objects.
    DisplayPort.begin();
    Display.init(/*115200*/);

    // Rotation de l'écran.
    // Bildschirm drehen.
    // Rotate the screen.
    Display.setRotation(3);

    // Remplissage de l'écran avec la couleur blanche (pour l'effacer).
    // Den Bildschirm mit weißer Farbe füllen (um ihn zu löschen).
    // Filling the screen with white color (to clear it).
    Display.fillScreen(GxEPD_WHITE);

    // Attribution de la couleur noir au texte affiché à l'écran.
    // Dem auf dem Bildschirm angezeigten Text die Farbe Schwarz zuweisen.
    // Assigning the color black to the text displayed on the screen.
    Display.setTextColor(GxEPD_BLACK);

    // Attribution de la police de caractères affichés à l'écran.
    // Zuweisung der auf dem Bildschirm angezeigten Schriftart.
    // Assignment of the font displayed on the screen.
    Display.setFont(&FreeMonoBold9pt7b);

    // Positionnement du curseur pour écrire à l'écran.
    // Positionierung des Cursors zum Schreiben auf dem Bildschirm.
    // Positioning the cursor to write on the screen.
    Display.setCursor(0,12);

    // Affichage du mot "Hello !" à l'écran.
    // Anzeige des Wortes „Hallo!“ auf dem Bildschirm.
    // Display of the word “Hello!” on the screen.
    Display.println("Hello !");

    // Mise à jour de l'écran pour prendre en compte les actions ci-dessus.
    // Der Bildschirm wurde aktualisiert, um die oben genannten Aktionen zu berücksichtigen.
    // Updated the screen to take into account the actions above.
    Display.update();
}


/**** DEFINITION DE LA FONCTION D'EXECUTION DU MODULE LILYGO T-ECHO ****/
/**** DEFINITION DER AUSFÜHRUNGSFUNKTION DES LILYGO T-ECHO-MODULS ****/
/**** DEFINITION OF THE EXECUTION FUNCTION OF THE LILYGO T-ECHO MODULE ****/
void loop()
{
  // On ne fait rien.
  // Wir tun nichts.
  // We do nothing.
}
